==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/sk_SK.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Zdieľanie server-server nie je na tomto serveri povolené",
    "The mountpoint name contains invalid characters." : "Názov pripojovacieho bodu obsahuje nepovolené znaky.",
    "Invalid or untrusted SSL certificate" : "Neplatný alebo nedôveryhodný certifikát SSL",
    "Could not authenticate to remote share, password might be wrong" : "Nie je možné overiť vo vzdialenom úložisku, heslo môže byť nesprávne",
    "Storage not valid" : "Neplatné úložisko",
    "Couldn't add remote share" : "Nemožno pridať vzdialené zdieľanie",
    "Shared with you" : "Zdieľané s vami",
    "Shared with others" : "Zdieľané s ostatnými",
    "Shared by link" : "Zdieľané pomocou odkazu",
    "Nothing shared with you yet" : "Zatiaľ s vami nikto nič nezdieľal.",
    "Files and folders others share with you will show up here" : "Tu budú zobrazené súbory a priečinky, ktoré s vami zdieľajú ostatní",
    "Nothing shared yet" : "Zatiaľ nie je nič zdieľané",
    "Files and folders you share will show up here" : "Súbory a priečinky, ktoré zdieľate, budú zobrazené tu",
    "No shared links" : "Žiadne zdieľané odkazy",
    "Files and folders you share by link will show up here" : "Súbory a priečinky, ktoré zdieľate ako odkazy, budú zobrazené tu",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Chcete pridať vzdialené úložisko {name} patriace používateľovi {owner}@{remote}?",
    "Remote share" : "Vzdialené úložisko",
    "Remote share password" : "Heslo k vzdialenému úložisku",
    "Cancel" : "Zrušiť",
    "Add remote share" : "Pridať vzdialené úložisko",
    "You can upload into this folder" : "Môžete nahrávať do tohto priečinka",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nebola nájdená inštalácia ownCloudu (7 alebo vyššia) {remote}",
    "Invalid ownCloud url" : "Chybná ownCloud url",
    "Shared by" : "Zdieľa",
    "Sharing" : "Zdieľanie",
    "A file or folder has been <strong>shared</strong>" : "Súbor alebo priečinok bol <strong>zdieľaný</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Súbor alebo priečinok bol vyzdieľaný z <strong>iného servera</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Verejne zdieľaný súbor alebo priečinok bol <strong>stiahnutý</strong>",
    "You received a new remote share %2$s from %1$s" : "Dostali ste nové vzdialené zdieľanie %2$s od používateľa %1$s",
    "You received a new remote share from %s" : "Dostali ste nové vzdialené zdieľanie z %s",
    "%1$s accepted remote share %2$s" : "%1$s povolil vzdialené zdieľanie %2$s",
    "%1$s declined remote share %2$s" : "%1$s odmietol vzdialené zdieľanie %2$s",
    "%1$s unshared %2$s from you" : "%1$s už s vami nezdieľa %2$s",
    "Public shared folder %1$s was downloaded" : "Verejne zdieľaný priečinok %1$s bol stiahnutý",
    "Public shared file %1$s was downloaded" : "Verejne zdieľaný súbor %1$s bol stiahnutý",
    "You shared %1$s with %2$s" : "Bol zdieľaný %1$s s %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s zdieľané %1$s s %3$s",
    "You shared %1$s with group %2$s" : "Bol zdieľaný %1$s so skupinou %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s zdieľané %1$s so skupinou %3$s",
    "%2$s shared %1$s via link" : "%2$s zdieľané %1$s pomocou linky",
    "You shared %1$s via link" : "Zdieľate %1$s prostredníctvom odkazu",
    "%2$s shared %1$s with you" : "%2$s vám zdieľal %1$s",
    "Downloaded via public link" : "Stiahnuté prostredníctvom verejného odkazu",
    "Shared with %2$s" : "Zdieľané s %2$s",
    "Shared with %3$s by %2$s" : "Zdieľané s %3$s prostredníctvom %2$s",
    "Shared with group %2$s" : "Zdieľané so skupinou %2$s",
    "Shared with group %3$s by %2$s" : "Zdieľané so skupinou %3$s prostredníctvom %2$s",
    "Shared via link by %2$s" : "Zdieľané prostredníctvom odkazu s %2$s",
    "Shared via public link" : "Zdieľané prostredníctvom verejného odkazu",
    "Shared by %2$s" : "Zdieľané s %2$s",
    "Shares" : "Zdieľanie",
    "Accept" : "Schváliť",
    "Decline" : "Odmietnuť",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Zdieľajte so mnou pomocou môjho #ownCloud Federated Cloud ID, viac n %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Zdieľajte so mnou pomocou môjho #ownCloud Federated Cloud ID",
    "This share is password-protected" : "Toto zdieľanie je chránené heslom",
    "The password is wrong. Try again." : "Heslo je chybné. Skúste to znova.",
    "Password" : "Heslo",
    "No entries found in this folder" : "V tomto priečinku nebolo nič nájdené",
    "Name" : "Názov",
    "Share time" : "Čas zdieľania",
    "Sorry, this link doesn’t seem to work anymore." : "To je nepríjemné, ale tento odkaz už nie je funkčný.",
    "Reasons might be:" : "Možné dôvody:",
    "the item was removed" : "položka bola presunutá",
    "the link expired" : "linke vypršala platnosť",
    "sharing is disabled" : "zdieľanie je zakázané",
    "For more info, please ask the person who sent this link." : "Pre viac informácií kontaktujte osobu, ktorá vám poslala tento odkaz.",
    "Add to your ownCloud" : "Pridať do svojho ownCloudu",
    "Download" : "Sťahovanie",
    "Download %s" : "Stiahnuť %s",
    "Direct link" : "Priama linka",
    "Federated Cloud Sharing" : "Združené cloudové zdieľanie",
    "Open documentation" : "Otvoriť dokumentáciu",
    "Allow users on this server to send shares to other servers" : "Povoliť používateľom z tohoto servera posielať zdieľania na iné servery",
    "Allow users on this server to receive shares from other servers" : "Povoliť používateľom z tohoto servera prijímať zdieľania z iných serverov",
    "Federated Cloud" : "Združený Cloud",
    "Your Federated Cloud ID:" : "Vaše združené Cloud ID",
    "Share it:" : "Zdieľať:",
    "Add to your website" : "Pridať na svoju webstránku",
    "Share with me via ownCloud" : "Zdieľané so mnou cez ownCloud",
    "HTML Code:" : "HTML kód:"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> owncloud-9.0.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/sk_SK.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Zdieľanie server-server nie je na tomto serveri povolené",
    "The mountpoint name contains invalid characters." : "Názov pripojovacieho bodu obsahuje nepovolené znaky.",
    "Invalid or untrusted SSL certificate" : "Neplatný alebo nedôveryhodný certifikát SSL",
    "Could not authenticate to remote share, password might be wrong" : "Nie je možné overiť vo vzdialenom úložisku, heslo môže byť nesprávne",
    "Storage not valid" : "Neplatné úložisko",
    "Couldn't add remote share" : "Nemožno pridať vzdialené zdieľanie",
    "Shared with you" : "Zdieľané s vami",
    "Shared with others" : "Zdieľané s ostatnými",
    "Shared by link" : "Zdieľané pomocou odkazu",
    "Nothing shared with you yet" : "Zatiaľ s vami nikto nič nezdieľal.",
    "Files and folders others share with you will show up here" : "Tu budú zobrazené súbory a priečinky, ktoré s vami zdieľajú ostatní",
    "Nothing shared yet" : "Zatiaľ nie je nič zdieľané",
    "Files and folders you share will show up here" : "Súbory a priečinky, ktoré zdieľate, budú zobrazené tu",
    "No shared links" : "Žiadne zdieľané odkazy",
    "Files and folders you share by link will show up here" : "Súbory a priečinky, ktoré zdieľate ako odkazy, budú zobrazené tu",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Chcete pridať vzdialené úložisko {name} patriace používateľovi {owner}@{remote}?",
    "Remote share" : "Vzdialené úložisko",
    "Remote share password" : "Heslo k vzdialenému úložisku",
    "Cancel" : "Zrušiť",
    "Add remote share" : "Pridať vzdialené úložisko",
    "You can upload into this folder" : "Môžete nahrávať do tohto priečinka",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nebola nájdená inštalácia ownCloudu (7 alebo vyššia) {remote}",
    "Invalid ownCloud url" : "Chybná ownCloud url",
    "Shared by" : "Zdieľa",
    "Sharing" : "Zdieľanie",
    "A file or folder has been <strong>shared</strong>" : "Súbor alebo priečinok bol <strong>zdieľaný</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Súbor alebo priečinok bol vyzdieľaný z <strong>iného servera</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Verejne zdieľaný súbor alebo priečinok bol <strong>stiahnutý</strong>",
    "You received a new remote share %2$s from %1$s" : "Dostali ste nové vzdialené zdieľanie %2$s od používateľa %1$s",
    "You received a new remote share from %s" : "Dostali ste nové vzdialené zdieľanie z %s",
    "%1$s accepted remote share %2$s" : "%1$s povolil vzdialené zdieľanie %2$s",
    "%1$s declined remote share %2$s" : "%1$s odmietol vzdialené zdieľanie %2$s",
    "%1$s unshared %2$s from you" : "%1$s už s vami nezdieľa %2$s",
    "Public shared folder %1$s was downloaded" : "Verejne zdieľaný priečinok %1$s bol stiahnutý",
    "Public shared file %1$s was downloaded" : "Verejne zdieľaný súbor %1$s bol stiahnutý",
    "You shared %1$s with %2$s" : "Bol zdieľaný %1$s s %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s zdieľané %1$s s %3$s",
    "You shared %1$s with group %2$s" : "Bol zdieľaný %1$s so skupinou %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s zdieľané %1$s so skupinou %3$s",
    "%2$s shared %1$s via link" : "%2$s zdieľané %1$s pomocou linky",
    "You shared %1$s via link" : "Zdieľate %1$s prostredníctvom odkazu",
    "%2$s shared %1$s with you" : "%2$s vám zdieľal %1$s",
    "Downloaded via public link" : "Stiahnuté prostredníctvom verejného odkazu",
    "Shared with %2$s" : "Zdieľané s %2$s",
    "Shared with %3$s by %2$s" : "Zdieľané s %3$s prostredníctvom %2$s",
    "Shared with group %2$s" : "Zdieľané so skupinou %2$s",
    "Shared with group %3$s by %2$s" : "Zdieľané so skupinou %3$s prostredníctvom %2$s",
    "Shared via link by %2$s" : "Zdieľané prostredníctvom odkazu s %2$s",
    "Shared via public link" : "Zdieľané prostredníctvom verejného odkazu",
    "Shared by %2$s" : "Zdieľané s %2$s",
    "Shares" : "Zdieľanie",
    "Accept" : "Schváliť",
    "Decline" : "Odmietnuť",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Zdieľajte so mnou pomocou môjho #ownCloud Federated Cloud ID, viac n %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Zdieľajte so mnou pomocou môjho #ownCloud Federated Cloud ID",
    "This share is password-protected" : "Toto zdieľanie je chránené heslom",
    "The password is wrong. Try again." : "Heslo je chybné. Skúste to znova.",
    "Password" : "Heslo",
    "No entries found in this folder" : "V tomto priečinku nebolo nič nájdené",
    "Name" : "Názov",
    "Share time" : "Čas zdieľania",
    "Sorry, this link doesn’t seem to work anymore." : "To je nepríjemné, ale tento odkaz už nie je funkčný.",
    "Reasons might be:" : "Možné dôvody:",
    "the item was removed" : "položka bola presunutá",
    "the link expired" : "linke vypršala platnosť",
    "sharing is disabled" : "zdieľanie je zakázané",
    "For more info, please ask the person who sent this link." : "Pre viac informácií kontaktujte osobu, ktorá vám poslala tento odkaz.",
    "Add to your ownCloud" : "Pridať do svojho ownCloudu",
    "Download" : "Sťahovanie",
    "Download %s" : "Stiahnuť %s",
    "Direct link" : "Priama linka",
    "Federated Cloud Sharing" : "Združené cloudové zdieľanie",
    "Open documentation" : "Otvoriť dokumentáciu",
    "Allow users on this server to send shares to other servers" : "Povoliť používateľom z tohoto servera posielať zdieľania na iné servery",
    "Allow users on this server to receive shares from other servers" : "Povoliť používateľom z tohoto servera prijímať zdieľania z iných serverov",
    "Federated Cloud" : "Združený Cloud",
    "Your Federated Cloud ID:" : "Vaše združené Cloud ID",
    "Share it:" : "Zdieľať:",
    "Add to your website" : "Pridať na svoju webstránku",
    "Share with me via ownCloud" : "Zdieľané so mnou cez ownCloud",
    "HTML Code:" : "HTML kód:",
    "Public shared file %1$s was downloaded" : "Verejne zdieľaný súbor %1$s bol stiahnutý",
    "Public shared folder %1$s was downloaded" : "Verejne zdieľaný priečinok %1$s bol stiahnutý",
    "Shared by %2$s" : "Zdieľané s %2$s",
    "Shared via link by %2$s" : "Zdieľané prostredníctvom odkazu s %2$s",
    "Shared with group %3$s by %2$s" : "Zdieľané so skupinou %3$s prostredníctvom %2$s"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
